@@ -1,12 +1,14 @@
 evaluate <-
   function(a, b, c, d, N = NULL, measure = "CCR"){
-    # version 1.3 (25 Mar 2024)
+    # version 1.4 (18 Sep 2025)
+    
     # internal function to be used by others in the package
     # a, b, c, d: elements of the confusion matrix (TP, FP, FN, TN)
     # N: sample size (total number of observations); calculated automatically if NULL
     # measure: evaluation measure to use
     # note: TSS and NMI are not symmetrical ("obs" vs "pred" != "pred" vs "obs")
     # note that some measures (e.g. NMI, odds ratio) don't work with zeros in (some parts of) the confusion matrix
+    
     if (is.null(N))  N <- a + b + c + d
     stopifnot(N == a + b + c + d)
     if (measure == "CCR") { value <- (a+d)/N
@@ -21,7 +23,12 @@ evaluate <-
     } else if(measure == "OPR") { value <- b/(a+b)
     } else if(measure == "PPI") { value <- ((a+b)/(a+c))-1
     } else if(measure == "PAI") { value <- ((c+d)/(b+d))-1
-    } else if(measure == "kappa") { value <- ((a+d)-(((a+c)*(a+b)+(b+d)*(c+d))/N))/(N-(((a+c)*(a+b)+(b+d)*(c+d))/N))
+    } else if(measure == "kappa") {
+      a <- as.numeric(a)  # to avoid integer overflow when large numbers (https://github.com/benjjneb/dada2/issues/1747#issuecomment-1579180381)
+      b <- as.numeric(b)
+      c <- as.numeric(c)
+      d <- as.numeric(d)
+      value <- ((a+d)-(((a+c)*(a+b)+(b+d)*(c+d))/N))/(N-(((a+c)*(a+b)+(b+d)*(c+d))/N))
     } else if(measure == "TSS") { value <- (a*d - b*c) / ((a+c) * (b+d))
     } else if(measure == "NMI") { value <- 1-((-a*log(a)-b*log(b)-c*log(c)-d*log(d)+(a+b)*log(a+b)+(c+d)*log(c+d))/(N*log(N)-((a+c)*log(a+c)+(b+d)*log(b+d))))  # NMI by Forbes (1995); the "1-" was missing in Fielding & Bell 1997 (and Manel et al 2001) but Fielding confirmed it was a typo
     } else if (measure == "F1score") {
